@@ -39,7 +39,7 @@ class PostgreSQLQueryStartWithDurationLine extends PostgreSQLQueryStartLine {
 		$database = $this->database ? $this->database : $logStream->getDatabase();
 		$user = $this->user ? $this->user : $logStream->getUser();
 		
-		$query = new QueryLogObject($user, $database, $this->text, $this->ignore);
+		$query = new QueryLogObject($this->getConnectionId(), $user, $database, $this->text, $this->ignore);
 		$query->setDuration($this->duration);
 		$query->setContextInformation($this->timestamp, $this->commandNumber);
 		
