@@ -47,6 +47,8 @@ class PostgreSQLParser {
 				} elseif($statusMatch =& $postgreSQLRegexps['StatusPart']->match($postMatch)) {
 						$line = new PostgreSQLStatusLine($postMatch);
 				} else {
+					// we ignore a lot of common log lines as they are not interesting
+					// but we still raise an error if we don't recognize a log line
 					if(
 						strpos($postMatch, 'transaction ID wrap limit is') !== 0 &&
 						strpos($postMatch, 'archived transaction log file') !== 0 &&
@@ -72,6 +74,8 @@ class PostgreSQLParser {
 				$line = new PostgreSQLHintLine($postMatch);
 			} elseif($keyword == 'DETAIL') {
 				$line = new PostgreSQLDetailLine($postMatch);
+			} elseif($keyword == 'NOTICE') {
+				$line = new PostgreSQLNoticeLine($postMatch);
 			}
 			if($line) {
 				$line->setLogLinePrefix($logLinePrefix);
