@@ -98,7 +98,12 @@ class ReportAggregator {
 	}
 	
 	function getPercentage($number, $total) {
-		return $this->pad(number_format($number*100/$total, 1), 5);
+		if($total > 0) {
+			$percentage = $number*100/$total;
+		} else {
+			$percentage = 0;
+		}
+		return $this->pad(number_format($percentage, 1), 5);
 	}
 	
 	function formatInteger($integer) {
@@ -109,8 +114,8 @@ class ReportAggregator {
 		return formatTimestamp($timestamp);
 	}
 	
-	function formatDuration($duration, $decimals = 2) {
-		return number_format($duration, $decimals);
+	function formatDuration($duration, $decimals = 2, $decimalPoint = '.', $thousandSeparator = ',') {
+		return number_format($duration, $decimals, $decimalPoint, $thousandSeparator);
 	}
 	
 	function formatLongDuration($duration, $decimals = 1) {
@@ -139,6 +144,20 @@ class ReportAggregator {
 		
 		return $formattedDuration;
 	}
+	
+	function formatRealQuery($query, $prepend = '', $append = '') {
+		return $prepend.$query->getText().$append;
+	}
+	
+	function containsReportBlock($reportBlockName) {
+		$count = count($this->reportBlocks);
+		for($i = 0; $i < $count; $i++) {
+			if(is_a($this->reportBlocks[$i], $reportBlockName)) {
+				return true;
+			}
+		}
+		return false;
+	}
 }
 
 ?>
\ No newline at end of file
